==> qore-0.9.10.tar.bz2: qore-0.9.10/docs/modules/RestHandler/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestHandler Module Reference", "index.html", [
    [ "RestHandler Module", "index.html", [
      [ "Introduction to the RestHandler Module", "index.html#resthandlerintro", null ],
      [ "Data Serialization Support", "index.html#restserialization", null ],
      [ "Implementing REST Services", "index.html#restimplementation", null ],
      [ "Implementing Object Hierarchies", "index.html#resthierarchy", null ],
      [ "Argument and Message Body Handling", "index.html#restargs", null ],
      [ "Exception Handling in REST Calls", "index.html#restexceptions", null ],
      [ "RestHandler Release Notes", "index.html#resthandler_relnotes", [
        [ "RestHandler v1.3.1", "index.html#rh_1_3_1", null ],
        [ "RestHandler v1.3", "index.html#rh_1_3", null ],
        [ "RestHandler v1.2.1", "index.html#rh_1_2_1", null ],
        [ "RestHandler v1.2", "index.html#rh_1_2", null ],
        [ "RestHandler v1.1", "index.html#rh_1_1", null ],
        [ "RestHandler v1.0.1", "index.html#rh_1_0_1", null ],
        [ "RestHandler v1.0", "index.html#rh_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.0.1.tar.bz2: qore-1.0.1/docs/modules/RestHandler/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestHandler Module Reference", "index.html", [
    [ "RestHandler Module", "index.html", [
      [ "Introduction to the RestHandler Module", "index.html#resthandlerintro", null ],
      [ "Data Serialization Support", "index.html#restserialization", null ],
      [ "Implementing REST Services", "index.html#restimplementation", null ],
      [ "Implementing Object Hierarchies", "index.html#resthierarchy", null ],
      [ "Argument and Message Body Handling", "index.html#restargs", null ],
      [ "Exception Handling in REST Calls", "index.html#restexceptions", null ],
      [ "RestHandler Release Notes", "index.html#resthandler_relnotes", [
        [ "RestHandler v1.3.1", "index.html#rh_1_3_1", null ],
        [ "RestHandler v1.3", "index.html#rh_1_3", null ],
        [ "RestHandler v1.2.1", "index.html#rh_1_2_1", null ],
        [ "RestHandler v1.2", "index.html#rh_1_2", null ],
        [ "RestHandler v1.1", "index.html#rh_1_1", null ],
        [ "RestHandler v1.0.1", "index.html#rh_1_0_1", null ],
        [ "RestHandler v1.0", "index.html#rh_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
